@@ -40,50 +40,19 @@
 # current calendar, just specify the path to pscal below.
 ####################################################################
 # specify the FULL PATH to pscal executable THIS ENABLES THE LINK
-$pscal = '/usr/bin/pscal';
+$pscal = '/usr/local/bin/pscal';
 # specify the FULL PATH to ps2pdf executable
-$ps2pdf = '/usr/bin/ps2pdf';
+$ps2pdf = '/usr/local/bin/ps2pdf';
 # A writable path for the script to place the PDF's of the calendars
 # This directory should allow for users to have read access.  Some
 # sometimes cgi-bin/ directories don't allow this so /var/www/html/
 # or www/ would be a good choice
-$calendar_path = '/var/www/html';
+$calendar_path = '/home/username/public_html';
 # URL to the same path for using in hyperlinks
-$calendar_url = 'http://www.yourserver.com/';
+$calendar_url = 'http://domain.com/';
+$csslink = 'http://domain.com/calendar.css';
 # Do you want to allow importing from Outlook .csv files?
 $import = 'yes';
 
 
-####################################################################
-# Colors
-####################################################################
-#Weekday Header background colors- the color that goes on Sunday, Monday, etc
-$weekdaybg		= '#879Ad4';
-#weekday font color-
-$weekdayfont		= '#FFFFFF';
-#day background color- the color of the calendar
-$daybg			= '#E7E9F5';
-#today's color
-$todaybg		= '#feffe8';
-#bgcolor if there is an event
-#$busydaybg		= '#FFFFCC';
-$busydaybg		= '#D9DFEF';
-
-#blank days (the padding) has a different background
-$blankday		= '#CDCDCD';
-#day font- the font of the date numbers, and the events
-$dayfont		= '#000000';
-#edit page colors
-$edittitlebg		= '#0D33A5';
-$edittitlefont		= '#FFFFFF';
-$editborder		= '#FCFCFC'; #note, these are most likely not what you think they are, try em
-$editbg			= '#FFFFFF';
-$editfont		= '#000000';
-
-# to customize the look of the site, simply edit the template.html file.  Make
-# sure you leave the <!-- content --> tag in wherever you would like for the 
-# calendar to be placed.
-
-
-#Leave this here or it breaks the script
 return 1;
